@@ -4,7 +4,7 @@
 
 """Tools for managing machine learning experiments."""
 
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 import logging
 import warnings
@@ -20,7 +20,7 @@ class DeprecationWarning(Warning):
 
 
 def deprecated(message):
-    warnings.warn(message, DeprecationWarning, stacklevel=3)
+    warnings.warn(message, DeprecationWarning, stacklevel=3) # pragma: no cover
 
 
 from threading import Timer
