@@ -10,30 +10,23 @@ define(["debug"], function(debug)
     // they can be used within grid widgets.
 
     var body = document.querySelector("body");
-    var dropdown_menu = null;
 
     body.addEventListener("show.bs.dropdown", function(event)
     {
-        var menu = event.target.parentElement.querySelector(".dropdown-menu");
+        var dropdown = event.target.parentElement;
+        var menu = dropdown.querySelector(".dropdown-menu");
         var parent_modal = menu.closest(".modal");
         if(!parent_modal)
         {
             body.appendChild(menu);
-        }
-    });
 
-/*
-    // If a dropdown is about to be hidden ...
-    jquery(window).on('hide.bs.dropdown', function(e)
-    {
-        // And it was previously reparented to the document body ...
-        if(dropdown_menu)
-        {
-            // Reparent the menu back where it came from.
-            jquery(e.target).append(dropdown_menu.detach());
-            dropdown_menu.hide();
-            dropdown_menu = null;
+            function close_dropdown(event)
+            {
+                dropdown.appendChild(menu);
+                body.removeEventListener("hidden.bs.dropdown", close_dropdown);
+            }
+
+            body.addEventListener("hidden.bs.dropdown", close_dropdown);
         }
     });
-*/
 });
